@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "tide" "5.1.3"
+(define-package "tide" "20260219.336"
   "Typescript Interactive Development Environment."
   '((emacs    "25.1")
     (dash     "2.10.0")
@@ -7,8 +7,8 @@
     (flycheck "27")
     (cl-lib   "0.5"))
   :url "https://github.com/ananthakumaran/tide"
-  :commit "bb09bccf070c1915ca8dbaaaaee4e9e3d7ab2ec7"
-  :revdesc "bb09bccf070c"
+  :commit "9498c4c7fc97d8042fdff532f47f1dc79ebd163a"
+  :revdesc "9498c4c7fc97"
   :keywords '("typescript")
   :authors '(("Anantha kumaran" . "ananthakumaran@gmail.com"))
   :maintainers '(("Anantha kumaran" . "ananthakumaran@gmail.com")))
